==> x-ui-vue3-0.2.1.tgz: package/esm/radio/Group.js <==
import { defineComponent, getCurrentInstance, provide, toRef, createVNode } from 'vue';
import { filterEmpty, getSlot } from '../_util/props-util/index.js';
import '../_util/hooks/index.js';
import { mapOptions } from '../_util/normalizeOptions.js';
import Radio from './Radio.js';
import useMemo from '../_util/hooks/useMemo.js';

const radioGroupContext = Symbol("radioGroupContext");
const prefixCls = "x-radio-group";
var RadioGroup = defineComponent({
  name: prefixCls,
  props: {
    name: String,
    options: Array,
    value: String,
    vertical: Boolean,
    disabled: Boolean
  },
  emits: ["update:value", "change"],
  setup(props, {
    emit
  }) {
    const {
      proxy: self
    } = getCurrentInstance();
    const val = useMemo(() => props.value);
    function onChange(e) {
      const val2 = e.target.value;
      val2.value = val2;
      emit("update:value", val2);
      emit("change", e);
    }
    provide(radioGroupContext, {
      disabledRef: toRef(props, "disabled"),
      nameRef: toRef(props, "name"),
      valueRef: toRef(val, "value"),
      onChange
    });
    return () => {
      var _a;
      let children;
      if ((_a = props.options) == null ? void 0 : _a.length) {
        children = mapOptions(props.options, (opt) => createVNode(Radio, {
          "key": opt.value,
          "checked": val.value == opt.value,
          "name": props.name,
          "value": opt.value,
          "disabled": opt.disabled || props.disabled,
          "style": opt.style
        }, {
          default: () => [opt.label]
        }));
      } else {
        children = filterEmpty(getSlot(self));
      }
      const cls = [prefixCls, props.vertical && `${prefixCls}-vertical`];
      return createVNode("div", {
        "class": cls
      }, [children]);
    };
  }
});

export { RadioGroup as default, radioGroupContext };

==> x-ui-vue3-0.2.5.tgz: package/esm/radio/Group.js <==
import { defineComponent, getCurrentInstance, provide, toRef, createVNode } from 'vue';
import { filterEmpty, getSlot } from '../_util/props-util/index.js';
import '../_util/hooks/index.js';
import { mapOptions } from '../_util/normalizeOptions.js';
import Radio from './Radio.js';
import useMemo from '../_util/hooks/useMemo.js';

const radioGroupContext = Symbol("radioGroupContext");
const prefixCls = "x-radio-group";
var RadioGroup = defineComponent({
  name: prefixCls,
  props: {
    name: String,
    options: Array,
    value: [String, Number],
    vertical: Boolean,
    disabled: Boolean
  },
  emits: ["update:value", "change"],
  setup(props, {
    emit
  }) {
    const {
      proxy: self
    } = getCurrentInstance();
    const value = useMemo(() => props.value);
    function onChange(val) {
      value.value = val;
      emit("update:value", val);
      emit("change", val);
    }
    provide(radioGroupContext, {
      disabledRef: toRef(props, "disabled"),
      nameRef: toRef(props, "name"),
      valueRef: value,
      onChange
    });
    return () => {
      var _a;
      let children;
      if ((_a = props.options) == null ? void 0 : _a.length) {
        children = mapOptions(props.options, (opt) => createVNode(Radio, {
          "key": opt.value,
          "checked": value.value == opt.value,
          "name": props.name,
          "value": opt.value,
          "disabled": opt.disabled || props.disabled,
          "style": opt.style
        }, {
          default: () => [opt.label]
        }));
      } else {
        children = filterEmpty(getSlot(self));
      }
      const cls = [prefixCls, props.vertical && `${prefixCls}-vertical`];
      return createVNode("div", {
        "class": cls
      }, [children]);
    };
  }
});

export { RadioGroup as default, radioGroupContext };
